==> 0.0.9.tar.gz: lib/Image/PIA_ImagePicker.dart <==
import 'dart:io' ;
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:pia_framework_base/Variable/PIA_Global.dart';
import 'package:pia_framework_base/View/PIA_Page.dart';
import 'package:pia_framework_base/Lang/PIA_Lang.dart';

class PIA_ImagePicker_CallBack
{   void Image_Picker_Callback(File image){} }

class PIA_ImagePicker
{  static PIA_ImagePicker_CallBack _callback;
   static BuildContext _context;
   static var _maxwidth = 0.0;


  static void show_bottom_sheet(BuildContext context,PIA_ImagePicker_CallBack callback,maxwidth) {
      _context = context;
      _callback = callback;
      _maxwidth = maxwidth;

      showModalBottomSheet(
      context: context,
      builder: (BuildContext context){
        return  Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            new ListTile(
              leading: new Icon(Icons.camera),
              title: new Text(camera[PIA_Lang.lang_id]),
              onTap: () {  Navigator.pop(context); _getCamera(); }
            ),
            new ListTile(
              leading: new Icon(Icons.photo_library),
              title: new Text(photo[PIA_Lang.lang_id]),
              onTap: () {  Navigator.pop(context);  _getImage(); }
            ),
          ],
        );
      }
  );}




   static Future _getImage() async {
     var image = await ImagePicker.pickImage(source: ImageSource.gallery,
      maxHeight: _maxwidth ,maxWidth: _maxwidth
     );
     if (_callback != null && image != null) {
          _get_image(image);
     }}

   static Future _getCamera() async {
     var image = await ImagePicker.pickImage(source: ImageSource.camera,
         maxHeight: _maxwidth,maxWidth: _maxwidth
         );
     if (_callback != null && image != null) {
         _get_image(image);
   }}


   static Future _get_image(File image) async {
     { _callback.Image_Picker_Callback(image); }
   }


}

==> 2.0.4.tar.gz: lib/Image/PIA_ImagePicker.dart <==
import 'dart:io' ;
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:pia_framework_base/Variable/PIA_Global.dart';
import 'package:pia_framework_base/Lang/PIA_Lang.dart';

class PIA_ImagePicker_CallBack
{   void Image_Picker_Callback(File image){} }

class PIA_ImagePicker
{  static PIA_ImagePicker_CallBack _callback;
   static BuildContext _context;
   static var _maxwidth = 0.0;


  static void show_bottom_sheet(BuildContext context,PIA_ImagePicker_CallBack callback,maxwidth) {
      _context = context;
      _callback = callback;
      _maxwidth = maxwidth;

      showModalBottomSheet(
      context: context,
      builder: (BuildContext context){
        return  Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            new ListTile(
              leading: new Icon(Icons.camera),
              title: new Text(camera[PIA_Lang.lang_id]),
              onTap: () {  Navigator.pop(context); _getCamera(); }
            ),
            new ListTile(
              leading: new Icon(Icons.photo_library),
              title: new Text(photo[PIA_Lang.lang_id]),
              onTap: () {  Navigator.pop(context);  _getImage(); }
            ),
          ],
        );
      }
  );}




   static Future _getImage() async {
     final picker = ImagePicker();
      var image = await picker.getImage(source: ImageSource.gallery,
      maxHeight: _maxwidth ,maxWidth: _maxwidth
     );
     if (_callback != null && image != null) {
       _get_image(File(image.path));
     }}

   static Future _getCamera() async {
     final picker = ImagePicker();
     var image = await picker.getImage(source: ImageSource.camera,
         maxHeight: _maxwidth ,maxWidth: _maxwidth
     );
     if (_callback != null && image != null) {
         _get_image(File(image.path));
   }}


   static Future _get_image(File image) async {
     { _callback.Image_Picker_Callback(image); }
   }


}
